Main automation module
=======================

.. automodule:: automan.automation
   :members:
   :undoc-members:


Utility functions for automation
=================================

.. automodule:: automan.utils
   :members:
   :undoc-members:


Low-level job management module
=================================

.. automodule:: automan.jobs
   :members:
   :undoc-members:

Cluster management module
=========================

.. automodule:: automan.cluster_manager
   :members:
   :undoc-members:

.. automodule:: automan.conda_cluster_manager
   :members:
   :undoc-members:

.. automodule:: automan.edm_cluster_manager
   :members:
   :undoc-members:
